
Reflection — ``selkie.pyx.reflect``
===================================

.. automodule:: selkie.pyx.reflect

.. autofunction:: load_module
.. autofunction:: import_class
.. autofunction:: class_name
.. autoclass:: FunctionInfo
.. autofunction:: MethodInfo
